UniversalSelector class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- UniversalSelector
Constructors
-
UniversalSelector({Key? key, required List<
SelectableItem> items, SelectableItem? selectedItem, List<SelectableItem> selectedItems = const [], dynamic onItemSelected(SelectableItem)?, dynamic onItemsSelected(List<SelectableItem> )?, String? labelText, String? hintText, bool showSubtitle = true, bool isMultiSelect = false, int? maxSelections, Color? backgroundColor, Color? headerColor, Color? textColor, Color? accentColor, Color? searchFieldColor, Color? searchFieldBorderColor, Color? cursorColor, Color? hintTextColor, Color? hoverColor, double? borderRadius}) -
const
Properties
- accentColor → Color?
-
final
- backgroundColor → Color?
-
final
- borderRadius → double?
-
final
- cursorColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerColor → Color?
-
final
- hintText → String?
-
final
- hintTextColor → Color?
-
final
- hoverColor → Color?
-
final
- isMultiSelect → bool
-
final
-
items
→ List<
SelectableItem> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String?
-
final
- maxSelections → int?
-
final
- onItemSelected → dynamic Function(SelectableItem)?
-
final
-
onItemsSelected
→ dynamic Function(List<
SelectableItem> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchFieldBorderColor → Color?
-
final
- searchFieldColor → Color?
-
final
- selectedItem → SelectableItem?
-
final
-
selectedItems
→ List<
SelectableItem> -
final
- showSubtitle → bool
-
final
- textColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< UniversalSelector> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited